@@ -8,6 +8,7 @@ from bloggart.core import config
 from bloggart.core import database
 from bloggart.core import fileserver
 from bloggart.core import service
+from bloggart.core import repeater
 # import socket
 # g_server_ip = socket.gethostbyname(socket.gethostname())
 import argparse
@@ -32,6 +33,7 @@ def Run():
     handler = []
     handler.extend(database.Handle(config.Get_database()))
     handler.extend(fileserver.Handle(config.Get_fileserver()))
+    handler.extend(repeater.Handle(config.Get_repeater()))
     service.Serving(int(args.port), handler)
     
     exit()
